@@ -1,17 +1,20 @@
 context("check-scrapeURLs-output")
 library(testthat)
+library(webmockr)
 library(archiveRetriever)
 
-
+#Two tests are skipped_on_cran as it is always possible that the Internet Archive might be inaccessible. For these two tests, it is also not possible to set use an vcr cassette as the cassette does not store the information required for the test to successfully fail. The tests, however, never failed when testing on our machines.
 
 #Check whether function output is data frame
 test_that("scrape_urls() returns a data frame", {
+  vcr::use_cassette("scrape_urls_01", {
   output <-
     scrape_urls(
-      "http://web.archive.org/web/20170131060045/http://www.ilsole24ore.com/art/mondo/2017-01-30/marine-pen-front-national-145809.shtml?uuid=AEPbqfK&nmll=2707",
-      Paths = c(title = "//header/h1", content = "//div[@class='entry entry-indent relative no_h']/p//text()"),
+      "http://web.archive.org/web/20190502052859/http://www.taz.de/Praesident-Trong-scheut-Oeffentlichkeit/!5588752/",
+      Paths = c(title = "//article//h1", content = "//article//p[contains(@class, 'article')]//text()"),
       encoding = "bytes"
     )
+  })
   expect_is(output, "data.frame")
 })
 
@@ -50,9 +53,9 @@ test_that("scrape_urls() only takes named XPath/CSS vector as Paths", {
   )
 })
 
-
 #Check whether Archive date is taken from the URL
 test_that("scrape_urls() option archiveDate stores archiving date", {
+  vcr::use_cassette("scrape_urls_02", {
   output <-
     scrape_urls(
       "http://web.archive.org/web/20170125090337/http://www.ilsole24ore.com/art/motori/2017-01-23/toyota-yaris-205049.shtml?uuid=AEAqSFG&nmll=2707",
@@ -66,18 +69,21 @@ test_that("scrape_urls() option archiveDate stores archiving date", {
     archiveDate = T,
     encoding = "bytes"
   )
+  })
   expect_equal(names(output)[4], "archiveDate")
 })
 
 
 #Check whether function takes CSS instead of XPath
 test_that("scrape_urls() takes CSS instead of XPath", {
+  vcr::use_cassette("scrape_urls_03", {
   output <-
     scrape_urls(
       "http://web.archive.org/web/20190528072311/https://www.taz.de/Fusionsangebot-in-der-Autobranche/!5598075/",
       Paths = c(title = "article h1"),
       CSS = T
     )
+  })
   expect_is(output, "data.frame")
 })
 
@@ -294,10 +300,10 @@ test_that("scrape_urls() needs encoding to be a character value", {
   )
 })
 
-
 #Check whether data is being correctly attached to existing data set
 test_that("scrape_urls() needs to fill first row when only second value is scraped",
           {
+            vcr::use_cassette("scrape_urls_04", {
             output <-
               scrape_urls(
                 c(
@@ -307,16 +313,17 @@ test_that("scrape_urls() needs to fill first row when only second value is scrap
                 c(title = "//header//h1"),
                 startnum = 2
               )
+            })
             expect_equal(is.na(output$title[1]), T)
           })
 
-
 #Check whether only some XPaths could be scraped
 test_that("scrape_urls() needs to warn if only some XPaths can be scraped", {
+  skip_on_cran()
   expect_warning(
     scrape_urls(
-      "http://web.archive.org/web/20170125090337/http://www.ilsole24ore.com/art/notizie/2015-06-08/le-razze-italiane-piccolo-levriero-italiano-204436.shtml",
-      Paths = c(title = "(//div[contains(@class,'title art11_title')]//h1 | //header/h1 | //h1[@class='atitle'] | //h1[@class='atitle '] | //article//article/header/h2[@class = 'title'])", content = "(//*[@class='grid-8 top art11_body body']//p//text() | //article/div[@class='article-content ']/div/div/div//p//text() | //div[@class='aentry aentry--lined']//p//text())"),
+      "http://web.archive.org/web/20190502052859/http://www.taz.de/Praesident-Trong-scheut-Oeffentlichkeit/!5588752/",
+      Paths = c(title = "/blablabla", content = "//article//p[contains(@class, 'article')]//text()"),
       ignoreErrors = F,
       encoding = "bytes"
     ),
@@ -327,6 +334,7 @@ test_that("scrape_urls() needs to warn if only some XPaths can be scraped", {
 
 #Check whether data is being correctly processed
 test_that("scrape_urls() needs to set NA if page cannot be scraped", {
+  vcr::use_cassette("scrape_urls_05", {
   output <-
     scrape_urls(
       c(
@@ -336,19 +344,21 @@ test_that("scrape_urls() needs to set NA if page cannot be scraped", {
       ),
       Paths = c(title = "//article//h1", content = "//article//p[contains(@class, 'article')]//text()")
     )
+  })
   expect_equal(is.na(output$title[3]), T)
 })
 
 
 #Check whether process stop if too many rows are empty
 test_that("scrape_urls() needs to stop if too many row are empty", {
+  skip_on_cran()
   expect_warning(
     scrape_urls(
       c(
         "http://web.archive.org/web/20190502052859/http://www.taz.de/Praesident-Trong-scheut-Oeffentlichkeit/!5588752/",
         "http://web.archive.org/web/20190502052859/http://blogs.taz.de/",
         "http://web.archive.org/web/20190502052859/http://blogs.taz.de/lostineurope",
-        "http://web.archive.org/web/20190502052859/http://blogs.taz.de/lostineurope/blogfeed/"
+        "http://web.archive.org/web/20190502052859/http://blogs.taz.de/lostineurope"
       ),
       Paths = c(title = "//article//h1", content = "//article//p[contains(@class, 'article')]//text()"),
       stopatempty = T,
@@ -361,6 +371,7 @@ test_that("scrape_urls() needs to stop if too many row are empty", {
 
 #Check if re-start after break and attachto works
 test_that("scrape_urls() needs to take up process if it breaks", {
+  vcr::use_cassette("scrape_urls_06", {
   output <-
     scrape_urls(
       c(
@@ -388,7 +399,7 @@ test_that("scrape_urls() needs to take up process if it breaks", {
         progress = c(1, 0, 0)
       )
     )
-
+  }, preserve_exact_body_bytes = TRUE)
   expect_equal(ncol(output), 3)
 })
 
@@ -465,6 +476,7 @@ test_that("scrape_urls() should not take up process if it stems from other proce
 #Check whether sleeper is activated after 20 Urls
 
 test_that("scrape_urls() needs to sleep every 20 Urls", {
+  vcr::use_cassette("scrape_urls_07", {
   output <-
     scrape_urls(
       c(
@@ -492,5 +504,27 @@ test_that("scrape_urls() needs to sleep every 20 Urls", {
       ),
       c(title = "//header//h1")
     )
+  })
   expect_equal(nrow(output), 21)
 })
+
+
+#Check whether script runs without problems in case of timeout of website
+test_that("scrape_urls() should not fail if website has timeout",
+          {
+
+            webmockr::enable()
+
+            webmockr::to_timeout(
+              webmockr::stub_request(
+                "get", "http://web.archive.org/web/20190502052859/http://www.taz.de/Praesident-Trong-scheut-Oeffentlichkeit/!5588752/")
+            )
+            output <- scrape_urls(
+              "http://web.archive.org/web/20190502052859/http://www.taz.de/Praesident-Trong-scheut-Oeffentlichkeit/!5588752/",
+              Paths = c(title = "//article//h1", content = "//article//p[contains(@class, 'article')]//text()"),
+              encoding = "bytes"
+            )
+            expect_is(output, "data.frame")
+
+            webmockr::disable()
+          })
